Index: trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/JFCSimplifiedLogParser.java
===================================================================
--- trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/JFCSimplifiedLogParser.java	(revision 984)
+++ trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/JFCSimplifiedLogParser.java	(revision 990)
@@ -136,5 +136,5 @@
      * </p> 
      */
-    private List<String> currentClassHierarchy;
+    private List<String> currentTypeHierarchy;
 
     /**
@@ -356,8 +356,8 @@
         }
         else if (qName.equals("ancestor")){
-        		currentClassHierarchy.add(atts.getValue("name"));
+        		currentTypeHierarchy.add(atts.getValue("name"));
         }
         else if (qName.equals("ancestors")){
-        		currentClassHierarchy = new LinkedList<String>();
+        		currentTypeHierarchy = new LinkedList<String>();
         }
     }
@@ -378,5 +378,5 @@
         }
         else if (qName.equals("ancestors")){
-        	currentGuiElementSpec.setClassHierarchy(currentClassHierarchy);
+        	currentGuiElementSpec.setTypeHierarchy(currentTypeHierarchy);
         }
         else if (qName.equals("component") && currentComponentHash != null) {
@@ -386,5 +386,5 @@
         	currentComponentHash = null;
         	currentParentHash = null;
-        	currentClassHierarchy = null;
+        	currentTypeHierarchy = null;
         }
         else if (currentEventId != null) {
Index: trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/guimodel/JFCGUIElementSpec.java
===================================================================
--- trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/guimodel/JFCGUIElementSpec.java	(revision 984)
+++ trunk/autoquest-plugin-jfc/src/main/java/de/ugoe/cs/autoquest/plugin/jfc/guimodel/JFCGUIElementSpec.java	(revision 990)
@@ -91,8 +91,8 @@
     /**
      * <p>
-     * Class hierarchy of the class itself
-     * </p>
-     */
-    private List<String> classHierarchy = null;
+     * Type hierarchy of the class itself
+     * </p>
+     */
+    private List<String> typeHierarchy = null;
 
     /*
@@ -374,10 +374,10 @@
     /**
      * <p>
-     * Sets the class hierarchy of the specified GUI element.
-     * @param classHierarchy
-     * </p>
-     */
-    public void setClassHierarchy(List<String> classHierarchy){
-    	this.classHierarchy = classHierarchy;
+     * Sets the type hierarchy of the specified GUI element.
+     * @param typeHierarchy
+     * </p>
+     */
+    public void setTypeHierarchy(List<String> typeHierarchy){
+    	this.typeHierarchy = typeHierarchy;
     }
 
@@ -421,10 +421,10 @@
 
     @Override
-    public String[] getClassHierarchy() {
-    	if (classHierarchy == null){
+    public String[] getTypeHierarchy() {
+    	if (typeHierarchy == null){
     		return new String[]{(getType())};
     	}
     	else
-    		return classHierarchy.toArray(new String[classHierarchy.size()]);
+    		return typeHierarchy.toArray(new String[typeHierarchy.size()]);
     }
 
